----------------------------------------------------------------------------------
-- Company: 
-- Engineer: Carl Mitchell
-- 
-- Create Date: 05/28/2017 11:55:13 AM
-- Design Name: 
-- Module Name: main - Behavioral
-- Project Name: 
-- Target Devices: 
-- Tool Versions: 
-- Description: 
-- 
-- Dependencies: 
-- 
-- Revision:
-- Revision 0.01 - File Created
-- Additional Comments:
-- 
----------------------------------------------------------------------------------


library IEEE;
use IEEE.STD_LOGIC_1164.ALL;

-- Uncomment the following library declaration if using
-- arithmetic functions with Signed or Unsigned values
use IEEE.NUMERIC_STD.ALL;

-- Uncomment the following library declaration if instantiating
-- any Xilinx leaf cells in this code.
library UNISIM;
use UNISIM.VComponents.all;

entity main is
    Port ( clk : in STD_LOGIC;
           rst : in STD_LOGIC;
           vauxp3 : in STD_LOGIC;
           vauxn3 : in STD_LOGIC;
           vauxp10 : in std_logic;
           vauxn10 : in std_logic;
           vauxp2  : in std_logic;
           vauxn2  : in std_logic;
           vauxp11 : in std_logic;
           vauxn11 : in std_logic;
           --rxd : in STD_LOGIC;      -- UART recieve. Not (yet) being used.
           txd : out STD_LOGIC;     -- UART transmit.
           --rts : out STD_LOGIC;     -- Request to Send
           --cts : in STD_LOGIC;      -- Clear to Send
           uart_led : out std_logic;
           adc_led : out std_logic);
end main;

architecture Behavioral of main is
component xadc_wiz_1 is
   port
   (
    daddr_in        : in  STD_LOGIC_VECTOR(6 downto 0);      -- Address bus for the dynamic reconfiguration port
    den_in          : in  STD_LOGIC;                         -- Enable Signal for the dynamic reconfiguration port
    di_in           : in  STD_LOGIC_VECTOR(15 downto 0);     -- Input data bus for the dynamic reconfiguration port
    dwe_in          : in  STD_LOGIC;                         -- Write Enable for the dynamic reconfiguration port
    do_out          : out  STD_LOGIC_VECTOR(15 downto 0);    -- Output data bus for dynamic reconfiguration port
    drdy_out        : out  STD_LOGIC;                        -- Data ready signal for the dynamic reconfiguration port
    dclk_in         : in  STD_LOGIC;                         -- Clock input for the dynamic reconfiguration port
    reset_in        : in  STD_LOGIC;                         -- Reset signal for the System Monitor control logic
    vauxp2          : in  STD_LOGIC;                         -- Auxiliary Channel 2
    vauxn2          : in  STD_LOGIC;
    vauxp3          : in  STD_LOGIC;                         -- Auxiliary Channel 3
    vauxn3          : in  STD_LOGIC;
    vauxp10         : in  STD_LOGIC;                         -- Auxiliary Channel 10
    vauxn10         : in  STD_LOGIC;
    vauxp11         : in  STD_LOGIC;                         -- Auxiliary Channel 11
    vauxn11         : in  STD_LOGIC;
    busy_out        : out  STD_LOGIC;                        -- ADC Busy signal
    channel_out     : out  STD_LOGIC_VECTOR(4 downto 0);     -- Channel Selection Outputs
    eoc_out         : out  STD_LOGIC;                        -- End of Conversion Signal
    eos_out         : out  STD_LOGIC;                        -- End of Sequence Signal
    alarm_out       : out STD_LOGIC;                         -- OR'ed output of all the Alarms
    vp_in           : in  STD_LOGIC;                         -- Dedicated Analog Input Pair
    vn_in           : in  STD_LOGIC
);
end component;
signal analogData : std_logic_vector(15 downto 0);
--signal eoc : std_logic;
--signal eos : std_logic;
signal drdy : std_logic;
constant daddr : std_logic_vector(6 downto 0) := "0010011"; -- hard selecting channel 3, IE JXADC pin 1 & 7 (rightmost, looking into the connector)
                                                            -- will sequence them later.
signal enable : std_logic;
signal channel_out : std_logic_vector(4 downto 0); -- channel selection
--signal alarm_out : std_logic;

component minimal_uart_tx is
    Port ( clk : in STD_LOGIC;
           bit_tick : in STD_LOGIC;
           data : in STD_LOGIC_VECTOR(7 downto 0);
           data_en : in STD_LOGIC;
           tx : out STD_LOGIC;
           busy : out STD_LOGIC);
end component;
signal count : unsigned(12 downto 0) := (others => '1');    -- Used to frequency divide the core clock to the transmit clock frequency.
signal bit_tick : std_logic := '0';                           -- Transmit clock tick.
constant clk_rate : unsigned(31 downto 0) := x"05F5E100";   -- 100000000, for 100 MHz clock.
constant baud_rate : unsigned(31 downto 0) := x"00002580";  -- 9600 baud

begin
    with count select bit_tick <= '1' when "0000000000000", '0' when others;
    
    uart_tx : minimal_uart_tx port map (
        clk => clk,
        data => analogData(15 downto 8),
        data_en => drdy,
        bit_tick => bit_tick,
        tx => txd,
        busy => uart_led);
        
    adc : xadc_wiz_1 port map (
        daddr_in => daddr,
        den_in => enable,
        di_in => (others => '0'),
        dwe_in => '0',
        do_out => analogData,
        drdy_out => drdy,
        dclk_in => clk,
        reset_in => rst,
        -- JXADC pins
        -- physical numbering and signals
        -- VCC GND 11  2   10  3
        -- 6   5   4   3   2   1 -- Positive
        -- 12  11  10  9   8   7 -- Negative
        vauxp2  => vauxp2, 
        vauxn2  => vauxn2,
        vauxp3  => vauxp3,
        vauxn3  => vauxn3,
        vauxp10 => vauxp10,
        vauxn10 => vauxn10,
        vauxp11 => vauxp11,
        vauxn11 => vauxn11,
        busy_out => adc_led,
        channel_out => channel_out,
        eoc_out => enable,
        eos_out => open,
        alarm_out => open,
        vp_in => '0',
        vn_in => '0'
        );
    
    --enable <= '1';
    process(clk)
    begin
        if rising_edge(clk) then
            if count = clk_rate/baud_rate-1 then
                count <= (others => '0');
            else
                bit_tick <= '0';
            end if;
        end if;
    end process;

end Behavioral;
