----------------------------------------------------------------------------------
-- Company: 
-- Engineer: Mike Field <hamster@snap.net.nz>, with edits by Carl Mitchell
-- 
-- Create Date: 05/28/2017 04:46:53 PM
-- Design Name: 
-- Module Name: minimal_uart_tx - Behavioral
-- Project Name: 
-- Target Devices: 
-- Tool Versions: 
-- Description: 
-- 
-- Dependencies: 
-- 
-- Revision:
-- Revision 0.01 - File Created
-- Additional Comments:
-- 
----------------------------------------------------------------------------------


library IEEE;
use IEEE.STD_LOGIC_1164.ALL;


entity minimal_uart_tx is
    Port ( clk : in STD_LOGIC;
           bit_tick : in STD_LOGIC;
           data : in STD_LOGIC_VECTOR(7 downto 0);
           data_en : in STD_LOGIC;
           tx : out STD_LOGIC;
           busy : out STD_LOGIC);
end minimal_uart_tx;

architecture Behavioral of minimal_uart_tx is
    signal shift_register : STD_LOGIC_VECTOR(9 downto 0);  -- Shift register to store the actual data to send
    signal txing          : STD_LOGIC;                     -- flag, are we transmitting data?
begin
    busy <= txing;
    with shift_register select
        txing <= '0' when "0000000000", '1' when others;
    
    clk_process : process(clk)
    begin
        if rising_edge(clk) then
            if txing = '0' and data_en = '1' then   -- If not transmitting, and there's data incoming, 
                                                    -- then load data with start and stop bits into the shift register
                shift_register <= '1' & data & '0'; -- Start bit, data, stop bit
            end if;
            
            if bit_tick = '1' and txing = '1' then                  -- Transmit clock is high and we have data to transmit
                tx <= shift_register(0);                            -- Shift out a bit of data
                shift_register <= '0' & shift_register(9 downto 1); -- and shift in a zero
            end if;
        end if;
    end process;

end Behavioral;
